@@ -5,6 +5,7 @@ from mosamatic2.commands import (
     segmentmusclefatl3tensorflow,
     createpngsfromsegmentations,
     dicom2nifti,
+    selectslicefromscans,
 )
 from mosamatic2.core.utils import show_doc_command
 
@@ -31,4 +32,5 @@ main.add_command(rescaledicomimages.rescaledicomimages)
 main.add_command(segmentmusclefatl3tensorflow.segmentmusclefatl3tensorflow)
 main.add_command(createpngsfromsegmentations.createpngsfromsegmentations)
 main.add_command(dicom2nifti.dicom2nifti)
+main.add_command(selectslicefromscans.selectslicefromscans)
 main.add_command(show_doc_command(main)) # Special command to show long description for command
\ No newline at end of file
